==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebLinearProgressDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebProgressBaseDescriptionMetadata } from "./WebProgressBaseDescriptionMetadata";
import { WebLinearProgressDescription } from "./WebLinearProgressDescription";
/**
 * @hidden
 */
export let WebLinearProgressDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebLinearProgressDescriptionMetadata extends Base {
        static b(a) {
            if (WebLinearProgressDescriptionMetadata.a == null) {
                WebLinearProgressDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebLinearProgressDescriptionMetadata.c(WebLinearProgressDescriptionMetadata.a);
            }
            if (a.k(WebLinearProgressDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebLinearProgressDescriptionMetadata.a);
        }
        static c(a) {
            WebProgressBaseDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:LinearProgress");
            a.item("__tagNameWC", "String:igc-linear-progress");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Striped", "Boolean");
            a.item("LabelAlign", "ExportedType:string:LinearProgressLabelAlign");
            a.item("LabelAlign@stringUnion", "WebComponents;React");
            a.item("LabelAlign@names", "Bottom;Top;TopStart;TopEnd;BottomStart;BottomEnd");
        }
        static d(a) {
            WebLinearProgressDescriptionMetadata.b(a);
            a.ad("WebLinearProgress", () => new WebLinearProgressDescription());
            a.ac("WebLinearProgress", WebLinearProgressDescriptionMetadata.a);
        }
    }
    WebLinearProgressDescriptionMetadata.$t = markType(WebLinearProgressDescriptionMetadata, 'WebLinearProgressDescriptionMetadata');
    WebLinearProgressDescriptionMetadata.a = null;
    return WebLinearProgressDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebLinearProgressDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebProgressBaseDescriptionMetadata } from "./WebProgressBaseDescriptionMetadata";
import { WebLinearProgressDescription } from "./WebLinearProgressDescription";
/**
 * @hidden
 */
export let WebLinearProgressDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebLinearProgressDescriptionMetadata extends Base {
        static b(a) {
            if (WebLinearProgressDescriptionMetadata.a == null) {
                WebLinearProgressDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebLinearProgressDescriptionMetadata.c(WebLinearProgressDescriptionMetadata.a);
            }
            if (a.k(WebLinearProgressDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebLinearProgressDescriptionMetadata.a);
        }
        static c(a) {
            WebProgressBaseDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:LinearProgress");
            a.item("__tagNameWC", "String:igc-linear-progress");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Striped", "Boolean");
            a.item("LabelAlign", "ExportedType:string:LinearProgressLabelAlign");
            a.item("LabelAlign@stringUnion", "WebComponents;React");
            a.item("LabelAlign@names", "TopStart;Top;TopEnd;BottomStart;Bottom;BottomEnd");
        }
        static d(a) {
            WebLinearProgressDescriptionMetadata.b(a);
            a.ae("WebLinearProgress", () => new WebLinearProgressDescription());
            a.ad("WebLinearProgress", WebLinearProgressDescriptionMetadata.a);
        }
    }
    WebLinearProgressDescriptionMetadata.$t = markType(WebLinearProgressDescriptionMetadata, 'WebLinearProgressDescriptionMetadata');
    WebLinearProgressDescriptionMetadata.a = null;
    return WebLinearProgressDescriptionMetadata;
})();
